import os
import logging
import json
from flask import Flask, render_template, abort, jsonify, session, url_for, request, redirect


from p2.ui.resources import settings
from p2.store.client import Client
from p2.logging import HttpLogger


app = Flask(__name__)
app.config.from_object('p2.ui.resources.settings')
app.secret_key = app.config['SECRET_KEY']

log = HttpLogger(
    level = logging.DEBUG,
    silent = False,
    name='p2.ui.resources'
)
logger = log.getLogger()

p2_store_url = os.getenv('P2_STORE_URL')
if p2_store_url is None:
    raise Exception("No P2_STORE_URL envar found")

client = Client(p2_store_url, timeout=20)

@app.route('/api/display_resources')
def display_resources_tree():
    # tree structure
    # org -> regions -> clusters -> resources
    # needed params: layer, kind, name 
    layer = request.args.get('layer')
    kind = request.args.get('kind')
    name = request.args.get('name')
    root = client.get_resources_faster(**{
        'layer': layer,
        'kind': kind,
        'name': name
    })
    if root is None:
        logger.error("No resources found for root :{}".format(request.args))
        return jsonify([])
    else:
        return jsonify([root])

@app.route('/api/get_distinct/<kind>')
def get_distinct_res_names(kind: str):
    """returns the list of distinct resource names of this kind"""
    return jsonify(client.select(
        table='resources',
        filter={'kind':kind},
        fetch=['distinct name'],
    ))

@app.route('/api/get_resource_profile/<id>')
def get_resource_profile(id: int):
    rec = client.select(
        table='resources',
        filter={'id': id},
        fetch=['profile'])
    if rec is None or len(rec) == 0 or rec[0]['profile'] is None:
        logger.warning(f"No profile found for resource {id}")
        return "No profile for this resource"
    else:
        return json.dumps(rec[0]['profile'], sort_keys=True, indent=2)
