function display_k8s_resources() {
    var selected_layer = 'k8';
    var res_workspace = `
        <div id="resWorkspace" width="100%" bp=12>
            <div id="resMenu" class="p2-menu" bp="flex">
                <div bp="fit"><span class="res-label">Organization</span></div>
                <div bp="fit" id="orgCombo" class="res-menu-combo"></div>
                <div bp="fit"><span class="res-label">Profile search</span></div>
                <input bp="fit" id="profileTextSearch" class="profile-search"/>
                <input bp="fit" type="button" value="Button" id="searchButton"/>
            </div>
            <div id="resLayout" class="res-layout">
                <div data-container="resTreeContainer">
                    <div id="resTreeGrid"></div>
                </div>
                <div data-container="resProfileContainer">
                    <div id="resProfilePanel"></div>
                </div>
            </div>
        </div>
    `;

    $("#appWorkspace").append(res_workspace);
    $("#profileTextSearch").jqxInput();
    create_profile_search_button();
    display_resources_layout();

    // organizations combo
    url = '/resources/api/get_distinct/org'
    var orgSource = {
        datatype: "json",
        datafields: [
            { name: 'name' }
        ],
        url: url
    };
    var orgDataAdapter = new $.jqx.dataAdapter(orgSource);
    $("#orgCombo").jqxComboBox({ 
        source: orgDataAdapter, 
        displayMember: "name", 
        valueMember: "name",
        // selectedIndex: 0,
        autoDropDownHeight: true
    });

    var selected_org;

    $("#orgCombo").on('select', function(event) {
        var args = event.args;
        if (args) {
            var item = args.item;
            selected_org = item.value;
        }
        console.log("Selected org: "+selected_org);

        var resTreeSource = {
            dataType: "json",
            dataFields: [
                {name: 'id', type: 'number'},
                {name: 'parent_id',     type: 'number'},
                {name: 'kind',          type: 'string'},
                {name: 'name',          type: 'string'},
                {name: 'creation_time', type: 'date'},
                {name: 'last_updated',  type: 'date'},
                {name: 'layer',         type: 'string'},
                {name: 'tag',           type: 'string'},
                {name: 'status',        type: 'string'},
                {name: 'children',     type: 'array' }
            ],
            hierarchy: { root: 'children' },
            id: 'id',
            url: "/resources/api/display_resources"+"?layer="+selected_layer+"&kind=org"+"&name="+selected_org
        };
        var resTreeDataAdapter = new $.jqx.dataAdapter(resTreeSource);

        $('#resTreeGrid').jqxTreeGrid({
            width: '100%',
            selectionMode: 'singlerow',
            sortable: true,
            filterable: true,
            filterMode: "advanced",
            pageable: true,
            pageSize: 20,
            pageSizeOptions: ['15', '20', '25', '50', '100'],
            source: resTreeDataAdapter,
            columns: [
                { text: 'Name', dataField: 'name', width: '50%' },
                { text: 'Kind', dataField: 'kind', width: '25%' },
                { text: 'Status', dataField: 'status', width: '25%' }
            ],
        });
        // $('#resTreeGrid').jqxTreeGrid('refresh');
        // $('#resTreeGrid').jqxTreeGrid('expandAll');

        $('#resTreeGrid').on('rowClick', 
            function (event) {
                // event args.
                var args = event.args;
                // row data.
                var row = args.row;
                console.log("Resource: "+row['id'])
                $.getJSON( '/resources/api/get_resource_profile/'+row['id'], function( d ) {
                    console.log("Got profile: "+d);
                    $("#resProfilePanel").empty();
                    document.getElementById("resProfilePanel").appendChild(renderjson.set_icons('+', '-').set_show_to_level(2)(d));
                });
            });
    });
}

function create_profile_search_button() {
    $("#searchButton").attr("value", "Search");
    $("#searchButton").jqxButton();
    $("#searchButton").on('click', function () {
        console.log("Profile search!");
    });
}

function display_resources_layout() {
    var layout = [{
        type: 'layoutGroup',
        orientation: 'horizontal',
        width: '100%',
        items: [{
            type: 'documentGroup',
            width: '50%',
            items: [{
                type: 'documentPanel',
                title: 'Resources Tree Grid View',
                contentContainer: 'resTreeContainer'
            }]
        },{
            type: 'documentGroup',
            width: '50%',
            items: [{
                type: 'documentPanel',
                title: 'Resource Profile',
                contentContainer: 'resProfileContainer'
            }]
        }]
    }];
    $('#resLayout').jqxLayout({ width: '100%', height: '100%', layout: layout });
}
