import unittest
import requests
import sys
import os
import json
import logging
from pprint import pprint

from p2.logging import HttpLogger

import http.client as http_client
http_client.HTTPConnection.debuglevel = 1

# You must initialize logging, otherwise you'll not see debug output.
logging.basicConfig(filename='server.log', level=logging.INFO)
requests_log = logging.getLogger("requests.packages.urllib3")
requests_log.setLevel(logging.INFO)
requests_log.propagate = True

base_url = 'http://localhost:6000'
headers = {'Content-Type': 'application/json' }

class TestResources(unittest.TestCase):

    def test_get_distinct_res_names(self):
        url = base_url + '/api/get_distinct/org'
        resp = requests.get(url, headers=headers, timeout=5)
        self.assertEqual( resp.status_code, 200)
        self.assertEqual( resp.json(), [{"name":"org 1"}])

    def test_display_resources(self):
        url = base_url + '/api/display_resources'
        qparams = {
            'kind': 'org',
            'name': 'org 1',
            'layer': 'k8'
        }
        resp = requests.get(
            url,
            json=qparams,
            headers=headers,
            timeout=10)
        self.assertEqual( resp.status_code, 200)
        tree = resp.json()
        pprint(tree)
        self.assertTrue(isinstance(tree, list))
        self.assertEqual(len(tree), 1)
        self.assertTrue(isinstance(tree[0], dict))
        self.assertEqual(tree[0]['kind'], 'org')

    def test_get_resource_profile(self):
        url = base_url + '/api/get_resource_profile/8'
        resp = requests.get(
            url,
            headers=headers,
            timeout=10)
        self.assertEqual( resp.status_code, 200)
        self.assertIsNotNone(resp.json())
        pprint (resp.json())

        url = base_url + '/api/get_resource_profile/1'
        resp = requests.get(
            url,
            headers=headers,
            timeout=10)
        self.assertEqual( resp.status_code, 200)
        self.assertEqual( resp.json(), 'No profile for this resource' )

